@@ -9,28 +9,28 @@ from __future__ import print_function
 from __future__ import absolute_import
 from __future__ import division
 
+import sys
+
 import argparse
 
 from ecl2df import (
-    grid,
-    nnc,
-    faults,
+    compdat,
     equil,
-    gruptree,
-    rft,
-    pillars,
+    faults,
     fipreports,
+    grid,
+    gruptree,
+    nnc,
+    pillars,
+    pvt,
+    rft,
     satfunc,
     summary,
     trans,
     wcon,
-    compdat,
 )
 
-from ._version import get_versions
-
-__version__ = get_versions()["version"]
-del get_versions
+from ecl2df import __version__
 
 
 def get_parser():
@@ -47,7 +47,13 @@ def get_parser():
         action="version",
         version="%(prog)s {version}".format(version=__version__),
     )
-    subparsers = parser.add_subparsers(parser_class=argparse.ArgumentParser)
+
+    if sys.version_info.major >= 3 and sys.version_info.minor >= 7:
+        subparsers = parser.add_subparsers(
+            required=True, dest="subcommand", parser_class=argparse.ArgumentParser
+        )
+    else:
+        subparsers = parser.add_subparsers(parser_class=argparse.ArgumentParser)
 
     # Eclipse output files:
     grid_parser = subparsers.add_parser(
@@ -62,7 +68,7 @@ def get_parser():
         formatter_class=argparse.ArgumentDefaultsHelpFormatter,
     )
     grid.fill_parser(grid_parser)
-    grid_parser.set_defaults(func=grid.grid2df_main)
+    grid_parser.set_defaults(func=grid.grid_main)
 
     summary_parser = subparsers.add_parser(
         "summary",
@@ -75,7 +81,7 @@ def get_parser():
         formatter_class=argparse.ArgumentDefaultsHelpFormatter,
     )
     summary.fill_parser(summary_parser)
-    summary_parser.set_defaults(func=summary.summary2df_main)
+    summary_parser.set_defaults(func=summary.summary_main)
 
     nnc_parser = subparsers.add_parser(
         "nnc",
@@ -90,7 +96,7 @@ def get_parser():
         ),
     )
     nnc.fill_parser(nnc_parser)
-    nnc_parser.set_defaults(func=nnc.nnc2df_main)
+    nnc_parser.set_defaults(func=nnc.nnc_main)
 
     faults_parser = subparsers.add_parser(
         "faults",
@@ -101,7 +107,7 @@ def get_parser():
         formatter_class=argparse.ArgumentDefaultsHelpFormatter,
     )
     faults.fill_parser(faults_parser)
-    faults_parser.set_defaults(func=faults.faults2df_main)
+    faults_parser.set_defaults(func=faults.faults_main)
 
     trans_parser = subparsers.add_parser(
         "trans",
@@ -117,7 +123,7 @@ def get_parser():
         ),
     )
     trans.fill_parser(trans_parser)
-    trans_parser.set_defaults(func=trans.trans2df_main)
+    trans_parser.set_defaults(func=trans.trans_main)
 
     pillars_parser = subparsers.add_parser(
         "pillars",
@@ -130,7 +136,25 @@ def get_parser():
         ),
     )
     pillars.fill_parser(pillars_parser)
-    pillars_parser.set_defaults(func=pillars.pillarstats_main)
+    pillars_parser.set_defaults(func=pillars.pillars_main)
+
+    pvt_parser = subparsers.add_parser(
+        "pvt",
+        help="Extract PVT data",
+        description=(
+            "Extract data for the PVT keywords in an Eclipse deck "
+            "and merge all data into a single dataframe. "
+            "Supported keywords are PVTO, PVDO, PVTG, PVDG, PVTW, "
+            "ROCK and DENSITY. Gas phase pressure and oil phase "
+            "pressure are both called PRESSURE in the resulting "
+            "dataframe, similar for volume factors and viscosity. "
+            "Deduce meaning for column names from the Eclipse manual. "
+            "The column KEYWORD denotes which PVT keyword a particular "
+            "data row stems from. "
+        ),
+    )
+    pvt.fill_parser(pvt_parser)
+    pvt_parser.set_defaults(func=pvt.pvt_main)
 
     rft_parser = subparsers.add_parser(
         "rft",
@@ -147,7 +171,7 @@ def get_parser():
         ),
     )
     rft.fill_parser(rft_parser)
-    rft_parser.set_defaults(func=rft.rft2df_main)
+    rft_parser.set_defaults(func=rft.rft_main)
 
     fipreports_parser = subparsers.add_parser(
         "fipreports",
@@ -176,7 +200,7 @@ def get_parser():
     )
 
     satfunc.fill_parser(satfunc_parser)
-    satfunc_parser.set_defaults(func=satfunc.satfunc2df_main)
+    satfunc_parser.set_defaults(func=satfunc.satfunc_main)
 
     compdat_parser = subparsers.add_parser(
         "compdat",
@@ -188,7 +212,7 @@ def get_parser():
         ),
     )
     compdat.fill_parser(compdat_parser)
-    compdat_parser.set_defaults(func=compdat.compdat2df_main)
+    compdat_parser.set_defaults(func=compdat.compdat_main)
 
     equil_parser = subparsers.add_parser(
         "equil",
@@ -197,7 +221,7 @@ def get_parser():
         description=("Each row contains the equilibriation data for one EQLNUM."),
     )
     equil.fill_parser(equil_parser)
-    equil_parser.set_defaults(func=equil.equil2df_main)
+    equil_parser.set_defaults(func=equil.equil_main)
 
     gruptree_parser = subparsers.add_parser(
         "gruptree",
@@ -206,7 +230,7 @@ def get_parser():
         description=("Each row represents an edge in the GRUPTREE at a specific date."),
     )
     gruptree.fill_parser(gruptree_parser)
-    gruptree_parser.set_defaults(func=gruptree.gruptree2df_main)
+    gruptree_parser.set_defaults(func=gruptree.gruptree_main)
 
     wcon_parser = subparsers.add_parser(
         "wcon",
@@ -218,7 +242,7 @@ def get_parser():
         ),
     )
     wcon.fill_parser(wcon_parser)
-    wcon_parser.set_defaults(func=wcon.wcon2df_main)
+    wcon_parser.set_defaults(func=wcon.wcon_main)
 
     return parser
 
