@@ -14,22 +14,23 @@ from __future__ import print_function
 from __future__ import division
 from __future__ import absolute_import
 
+import os
 import sys
 import logging
 import argparse
 import fnmatch
+import textwrap
 import datetime
 import dateutil.parser
 
 import numpy as np
 import pandas as pd
 
-import ecl2df
+from ecl2df import common, __version__
+
 from ecl.eclfile import EclFile
 from .eclfiles import EclFiles
 
-from .common import merge_zones
-
 logging.basicConfig()
 logger = logging.getLogger(__name__)
 
@@ -139,7 +140,11 @@ def rst2df(eclfiles, date, vectors=None, dateinheaders=False, stackdates=False):
             dateinheaders False.
     """
     if not vectors:
+        vectorswasdefaulted = True
         vectors = "*"  # This will include everything
+    else:
+        vectorswasdefaulted = False
+
     if not isinstance(vectors, list):
         vectors = [vectors]
     logger.info("Extracting vectors %s from RST file", str(vectors))
@@ -184,7 +189,10 @@ def rst2df(eclfiles, date, vectors=None, dateinheaders=False, stackdates=False):
             str(present_rstvectors),
         )
         if not present_rstvectors:
-            logger.warning("No restart vectors available at index %s", str(rstindex))
+            if vectorswasdefaulted:
+                logger.warning(
+                    "No restart vectors available at index %s", str(rstindex)
+                )
             continue
 
         # Make the dataframe
@@ -239,7 +247,8 @@ def gridgeometry2df(eclfiles):
         eclfiles (EclFiles): object holding the Eclipse output files.
 
     Returns:
-        DataFrame: With columns I, J, K, X, Y, Z, VOLUME, one row pr. cell.
+        DataFrame: With columns I, J, K, X, Y, Z, VOLUME, one row pr. cell. The
+        index of the dataframe are the global indices
     """
     if not eclfiles:
         raise ValueError
@@ -249,7 +258,7 @@ def gridgeometry2df(eclfiles):
     if not egrid_file or not grid:
         raise ValueError("No EGRID file supplied")
 
-    logger.info("Extracting grid geometry from %s", str(egrid_file))
+    logger.info("Extracting grjd geometry from %s", str(egrid_file))
     index_frame = grid.export_index(active_only=True)
     ijk = index_frame.values[:, 0:3] + 1  # ijk from ecl.grid is off by one
 
@@ -257,9 +266,12 @@ def gridgeometry2df(eclfiles):
     vol = grid.export_volume(index_frame)
     grid_df = pd.DataFrame(
         index=index_frame["active"],
-        columns=["i", "j", "k", "x", "y", "z", "volume"],
-        data=np.hstack((ijk, xyz, vol.reshape(-1, 1))),
+        columns=["i", "j", "k", "x", "y", "z", "volume", "global_index"],
+        data=np.hstack(
+            (ijk, xyz, vol.reshape(-1, 1), np.array(index_frame.index).reshape(-1, 1))
+        ),
     )
+
     # Type conversion, hstack maybe ruined the datatypes..
     grid_df["i"] = grid_df["i"].astype(int)
     grid_df["j"] = grid_df["j"].astype(int)
@@ -271,7 +283,7 @@ def gridgeometry2df(eclfiles):
     zonemap = eclfiles.get_zonemap()
     if zonemap:
         logger.info("Merging zonemap into grid")
-        grid_df = merge_zones(grid_df, zonemap, kname="K")
+        grid_df = common.merge_zones(grid_df, zonemap, kname="K")
 
     return grid_df
 
@@ -279,7 +291,8 @@ def gridgeometry2df(eclfiles):
 def merge_initvectors(eclfiles, dframe, initvectors, ijknames=None):
     """Merge in INIT vectors to a dataframe by I, J, K.
 
-    Utility function for other modules to use.
+    Utility function for other modules to use. Normally it is sufficient
+    for API users to only use the df() function.
 
     Args:
         eclfiles (EclFiles): Object representing the Eclipse output files
@@ -316,6 +329,9 @@ def merge_initvectors(eclfiles, dframe, initvectors, ijknames=None):
 def init2df(eclfiles, vectors=None):
     """Extract information from INIT file with cell data
 
+    Normally, you would use the df() function which will
+    call this function on your behalf.
+
     Order is significant, as index is used for merging
 
     Args:
@@ -353,6 +369,13 @@ def init2df(eclfiles, vectors=None):
                 ]
             ),
         )
+        # libecl emits a number around -1.0000000200408773e+20 which
+        # should be considered Not-a-number
+        init_df = init_df.where(init_df > -1e20 + 1e13)  # some trial and error
+
+        # Remove columns that are all NaN:
+        init_df.dropna(axis="columns", how="all", inplace=True)
+
     else:
         init_df = pd.DataFrame()  # empty
 
@@ -385,12 +408,12 @@ def df(
     Args:
         eclfiles (EclFiles): Handle to an Eclipse case
         vectors (str or list): Vectors to include, wildcards
-            supported. String argument. Used to match both
+            supported. Used to match both
             INIT vectors and RESTART vectors.
         dropconstants (bool): If true, columns that are constant
             for every cell are dropped.
-        rstdates (list, str or datetime): Restart dates to include
-            Mnenomics such as first and last are supported.
+        rstdates (list, str or datetime): Restart dates to include in ISO-8601 format.
+            Alternatively, pick from the mnenomics 'first', 'all' and 'last'.
         dateinheaders (bool): Whether columns with data from UNRST files
             should always have the ISO-date embedded in the column header.
         stackdates (bool): Default is false. If true, a column
@@ -409,19 +432,12 @@ def df(
             dateinheaders=dateinheaders,
             stackdates=stackdates,
         )
-    grid_df = merge_gridframes(gridgeom, initdf, rst_df)
+    grid_df = pd.concat([gridgeom, initdf, rst_df], axis=1, sort=False)
     if dropconstants:
-        # Note: Ambigous object names, bool vs function
-        grid_df = ecl2df.grid.dropconstants(grid_df)
+        grid_df = drop_constant_columns(grid_df)
     return grid_df
 
 
-def merge_gridframes(grid_df, init_df, rst_df):
-    """Merge dataframes with grid data"""
-    merged = pd.concat([grid_df, init_df, rst_df], axis=1, sort=False)
-    return merged
-
-
 def fill_parser(parser):
     """Set up sys.argv parser.
 
@@ -433,16 +449,18 @@ def fill_parser(parser):
         help="Name of Eclipse DATA file. " + "INIT and EGRID file must lie alongside.",
     )
     parser.add_argument(
-        "--initkeys",
+        "--vectors",
+        "--initkeys",  # --initkeys is deprecated
         nargs="+",
-        help="INIT vector wildcards for vectors to include",
+        help="INIT and/or restart wildcards for vectors to include",
         default="*",
     )
     parser.add_argument(
-        "--rstdate",
+        "--rstdates",
+        "--rstdate",  # --rstdate is deprecated
         type=str,
         help="Point in time to grab restart data from, "
-        + "either 'first' or 'last', or a date in "
+        + "either 'first' or 'last', 'all', or a date in "
         + "YYYY-MM-DD format",
         default="",
     )
@@ -450,9 +468,19 @@ def fill_parser(parser):
         "-o",
         "--output",
         type=str,
-        help="Name of output csv file.",
+        help="Name of output csv file. Use '-' for stdout.",
         default="eclgrid.csv",
     )
+    parser.add_argument(
+        "--stackdates",
+        action="store_true",
+        help=(
+            "If set, the dates from restart data will not be in the column "
+            "but instead there will be a DATE column with the dates. Note "
+            "that the static data will be repeated for each DATE."
+        ),
+    )
+
     parser.add_argument(
         "--dropconstants",
         action="store_true",
@@ -462,7 +490,7 @@ def fill_parser(parser):
     return parser
 
 
-def dropconstants(dframe, alwayskeep=None):
+def drop_constant_columns(dframe, alwayskeep=None):
     """Drop/delete constant columns from a dataframe.
 
     Args:
@@ -492,24 +520,142 @@ def dropconstants(dframe, alwayskeep=None):
     return dframe.drop(columnstodelete, axis=1)
 
 
-def grid2df(eclfiles, vectors="*"):
-    """Produce a grid dataframe from EclFiles
-
-    Given a set of Eclipse files (an EclFiles object), this
-    function will return a dataframe with a row for each cell
-    including cell coordinates and volume and any requested data
-    for the cell
-
-    Arguments:
-        eclfiles (EclFiles): Object holding the set of Eclipse output files
-        vectors (str or list): List of vectors to include,
-            glob-style wildcards supported
-
-    Returns:
-        pandas.DataFrame
+def df2ecl(
+    grid_df, keywords, eclfiles=None, dtype=None, filename=None, nocomments=False
+):
     """
+    Write an include file with grid data keyword, like PERMX, PORO,
+    FIPNUM etc, for the GRID section of the Eclipse deck.
 
-    return merge_gridframes(gridgeometry2df(eclfiles), init2df(eclfiles, vectors), None)
+    Output (returned as string and optionally written to file) will then
+    contain f.ex:
+
+        PERMX
+           3.3 4.1 500.1 8543.0 1223.0 5022.0
+           411.455 4433.9
+        /
+
+    if the grid contains 8 cells (inactive and active).
+
+    Args:
+        grid_df (pd.DataFrame). Dataframe with the keyword for which
+            we want to export data, and also the a column with GLOBAL_INDEX.
+            Without GLOBAL_INDEX, the output will likely be invalid.
+            The grid can contain both active and inactive cells.
+        keywords (str or list of str): The keyword(s) to export, with one value for every cell.
+        eclfiles (EclFiles): If provided, the total cell count for the grid
+            will be requested from this object. If not, it will be *guessed*
+            from the maximum number of GLOBAL_INDEX, which can be under-estimated
+            in the corner-case that the last cells are inactive.
+        dtype (float or int-class): If provided, the columns which are
+            outputted are converted to int or float. Dataframe columns
+            read from CSV files easily gets the wrong type, while Eclipse
+            might require some data to be strictly integer.
+        filename (str): If provided, the string produced will also to be
+            written to this filename.
+        nocomments (bool): Set to True to avoid any comments being written. Defaults
+            to False.
+    """
+    if isinstance(keywords, str):
+        keywords = [keywords]
+
+    if isinstance(dtype, str):
+        if dtype.startswith("int"):
+            dtype = int
+        elif dtype.startswith("float"):
+            dtype = float
+        else:
+            raise ValueError("Wrong dtype argument {}".format(dtype))
+
+    # Figure out the total number of cells for which we need to export data for:
+    global_size = None
+    active_cells = None
+    if eclfiles is not None:
+        if eclfiles.get_egrid() is not None:
+            global_size = eclfiles.get_egrid().get_global_size()
+            active_cells = eclfiles.get_egrid().getNumActive()
+
+    if "GLOBAL_INDEX" not in grid_df:
+        logger.warning(
+            (
+                "Global index not found in grid dataframe. "
+                "Assumes all cells are active"
+            )
+        )
+        # Drop NaN rows for columns to be used (triggerd by stacked dates and no global index, unlikely)
+        # Also copy dataframe to avoid side-effects on incoming data.
+        grid_df = grid_df.dropna(
+            axis="rows", subset=[keyword for keyword in keywords if keyword in grid_df]
+        )
+        grid_df["GLOBAL_INDEX"] = grid_df.index
+
+    if global_size is None:
+        global_size = int(grid_df["GLOBAL_INDEX"].max() + 1)
+        active_cells = len(grid_df[grid_df.index >= 0])
+        logger.warning("Global grid size estimated to %s", str(global_size))
+
+    ecl2df_header = (
+        "Output file printed by "
+        + "ecl2df.grid "
+        + __version__
+        + "\n"
+        + " at "
+        + str(datetime.datetime.now())
+    )
+
+    string = ""
+    if not nocomments:
+        string += common.comment_formatter(ecl2df_header)
+    string += "\n"
+
+    # If we have NaNs in the dataframe, we will be more careful (costs memory)
+    if grid_df.isna().any().any():
+        grid_df = grid_df.dropna(
+            axis="rows", subset=[keyword for keyword in keywords if keyword in grid_df]
+        )
+
+    for keyword in keywords:
+        if keyword not in grid_df.columns:
+            raise ValueError("Keyword {} not found in grid dataframe".format(keyword))
+        vector = np.zeros(global_size)
+        vector[grid_df["GLOBAL_INDEX"].astype(int).values] = grid_df[keyword]
+        if dtype == int:
+            vector = vector.astype(int)
+        if dtype == float:
+            vector = vector.astype(float)
+        if len(vector) != global_size:
+            logger.warning(
+                "Mismatch between dumped vector length %d from df2ecl and assumed grid size %d",
+                len(vector),
+                global_size,
+            )
+            logger.warning("Data will be dumped, but may error in simulator")
+        strvector = "  ".join([str(x) for x in vector])
+        strvector = common.runlength_eclcompress(strvector)
+
+        string += keyword + "\n"
+        indent = " " * 5
+        string += "\n".join(
+            textwrap.wrap(
+                strvector, initial_indent=indent, subsequent_indent=indent, width=70
+            )
+        )
+        string += "\n/"
+        if not nocomments:
+            string += " -- {}: {} active cells, {} total cell count\n".format(
+                keyword, active_cells, global_size
+            )
+        string += "\n"
+
+    if filename is not None:
+        # Make directory if not present:
+        filenamedir = os.path.dirname(filename)
+        if filenamedir and not os.path.exists(filenamedir):
+            os.makedirs(filenamedir)
+        with open(filename, "w") as file_handle:
+            file_handle.write(string)
+
+    return string
 
 
 def main():
@@ -519,19 +665,20 @@ def main():
     parser = argparse.ArgumentParser()
     parser = fill_parser(parser)
     args = parser.parse_args()
-    grid2df_main(args)
+    grid_main(args)
 
 
-def grid2df_main(args):
+def grid_main(args):
     """This is the command line API"""
     if args.verbose:
         logger.setLevel(logging.INFO)
     eclfiles = EclFiles(args.DATAFILE)
     grid_df = df(
         eclfiles,
-        vectors=args.initkeys,
-        rstdates=args.rstdate,
+        vectors=args.vectors,
+        rstdates=args.rstdates,
         dropconstants=args.dropconstants,
+        stackdates=args.stackdates,
     )
     if args.output == "-":
         # Ignore pipe errors when writing to stdout.
